IANA
====

Enumeration values taken from the IANA registries for TLS, along with
various other enumerations that fit nicely here.

The registries are available online at `TLS Parameters`_ and
`TLS Extensions`_.

.. _TLS Parameters: https://www.iana.org/assignments/tls-parameters/
.. _TLS Extensions: https://www.iana.org/assignments/tls-extensiontype-values/

.. module:: siotls.iana

   .. autoclass:: AlertDescription
      :members:
      :undoc-members:

   .. autoclass:: AlertLevel
      :members:
      :undoc-members:

   .. autoclass:: ALPNProtocol
      :members:
      :undoc-members:

   .. autoclass:: CertificateStatusType
      :members:
      :undoc-members:

   .. autoclass:: CertificateType
      :members:
      :undoc-members:

   .. autoclass:: CipherSuites
      :members:
      :undoc-members:

   .. autoclass:: ContentType
      :members:
      :undoc-members:

   .. autoclass:: ExtensionType
      :members:
      :undoc-members:

   .. autoclass:: HandshakeType
      :members:
      :undoc-members:

   .. autoclass:: HandshakeType_
      :members:
      :undoc-members:

   .. autoclass:: HeartbeatMessageType
      :members:
      :undoc-members:

   .. autoclass:: HeartbeatMode
      :members:
      :undoc-members:

   .. autoclass:: MaxFragmentLengthCode
      :members:
      :undoc-members:

   .. autoclass:: MaxFragmentLengthOctets
      :members:
      :undoc-members:

   .. autoclass:: NamedGroup
      :members:
      :undoc-members:

   .. autoclass:: NameType
      :members:
      :undoc-members:

   .. autoclass:: PskKeyExchangeMode
      :members:
      :undoc-members:

   .. autoclass:: SignatureScheme
      :members:
      :undoc-members:

   .. autoclass:: TLSVersion
      :members:
      :undoc-members:

